==> php81-nextcloud-26.0.5.tgz: share/nextcloud/apps/activity/l10n/ko.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "복사 성공!",
    "Not supported!" : "지원하지 않음!",
    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
    "{name} (invisible)" : "{name} (숨겨짐)",
    "{name} (restricted)" : "{name} (제한됨)",
    "Home" : "홈",
    "in {path}" : "{path}에 있음",
    "This stream will show events like additions, changes & shares" : "스트림에는 추가, 변경, 공유와 같은 이벤트가 표시됩니다",
    "There are no events for this filter" : "이 필터를 만족하는 이벤트 없음",
    "Today" : "오늘",
    "Yesterday" : "어제",
    "Open {filename}" : "{filename} 열기",
    "Activity" : "활동",
    "Personal activity feed for %s" : "%s 님의 개인 활동 피드",
    "Your feed URL is invalid" : "피드 주소가 잘못되었습니다",
    "Your settings have been updated." : "설정이 업데이트되었습니다.",
    "Settings have been updated." : "설정이 업데이트되었습니다.",
    "Recent activity" : "최근 활동",
    "More activities" : "더 많은 활동",
    "Daily activity summary for %s" : "%s 의 일일 활동 요약",
    "_and %n more _::_and %n more _" : ["%n개 더"],
    "All activities" : "모든 활동",
    "By others" : "다른 사람",
    "By you" : "나",
    "Activity at %s" : "%s에 활동",
    "Hello %s" : "%s 님 안녕하세요",
    "Hello %s," : "%s 님 안녕하세요,",
    "There was some activity at %s" : "%s에 새로운 활동이 있었습니다",
    "Mail" : "메일",
    "Push" : "푸시",
    "Notifications" : "알림",
    "This application enables people to view a log of activities about them, their files or other data." : "이 애플리케이션은 사용자, 파일, 혹은 기타 데이터와 관련된 활동 내역을 볼 수 있도록 합니다.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "이 앱은 Nextcloud에 존재하는 사용자의 파일, 데이터 관련 활동을 볼 수 있도록 합니다.\n\n\t\t각 사용자는 개인 설정에서 개인 활동에 관한 설정을 할 수 있습니다.\n\t\t특정 활동을 지정하여 푸시 알림, 이메일 알림을 전송하거나\n\t\t매일 아침 요악본을 발송하도록 할 수 있습니다.\n\t\t더 자세한 정보는 Activity 문서를 참고하십시오.",
    "Activity notification configuration" : "활동 알림 설정",
    "Send email" : "이메일 보내기",
    "Send push notification" : "푸시 알림 발송",
    "You need to set up your email address before you can receive notification emails." : "알림 이메일을 받으려면 이메일 주소를 설정해야 합니다.",
    "Send activity emails" : "활동 이메일 보내기",
    "As soon as possible" : "빠른 시일 내에",
    "Hourly" : "1시간마다",
    "Daily" : "매일",
    "Weekly" : "매주",
    "No activity yet" : "아직 활동 없음",
    "Notification" : "알림",
    "Enable notification emails" : "이메일 알림 활성화",
    "Choose for which activities you want to get an email or push notification." : "이메일 혹은 푸시 알림을 받을 활동을 선택합니다.",
    "Choose for which activities you want to get a push notification." : "푸시 알림을 받을 활동을 선택합니다.",
    "Daily activity summary" : "일간 활동 요약",
    "Send daily activity summary in the morning" : "매일 아침 일일 활동내역 전송",
    "Activities" : "활동",
    "No activities" : "활동 없음",
    "Default settings" : "기본 설정",
    "Configure the default notification settings for new accounts." : "알림에 관한 기본값을 설정하십시오.",
    "Unable to save the settings" : "설정을 저장할 수 없습니다.",
    "Activity feed" : "활동 피드",
    "Activity settings" : "활동 설정",
    "Enable RSS feed" : "RSS 피드 사용",
    "RSS feed" : "RSS 피드",
    "Copy RSS feed link" : "RSS 피드 링크 복사",
    "Personal notification settings" : "개인 알림 설정",
    "No more events to load" : "더 이상 불러올 이벤트 없음",
    "This application enables users to view a log of activities about them or about files." : "이 응용 프로그램을 사용하면 사용자가 자신 또는 파일에 대한 활동 로그를 볼 수 있습니다.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "이 애플리케이션은 사용자들이 Nextcloud에서 파일 관련 활동을 볼 수 있도록 합니다. \n\t\t활성화되면 사용자는 앱 매뉴에서 새 아이콘 \"활동\"을 볼 수 있습니다.\n\t\t이 아이콘을 누르면 사용자의 새 파일 생성이나 파일 삭제, 이동, 이름 변경, 업데이트나 공유 활동 등의 파일 관련 활동을 보여 주는 새 페이지가 열립니다.\n\t\t사용자는 개인 메뉴에서 개별 활동 설정을 변경할 수 있습니다.\n\t\t이 메뉴는 활동의 종류나, 사용자 자신의 활동을 볼 것인지,\n\t\t또는 온라인 상태에서만 확인하거나 정기적으로 이메일 알림을 받을 것인지를 선택할 수 있습니다.\n\t\t더 자세한 설명은 Activity 문서를 참고하십시오.",
    "Unable to load the activity list" : "활동 목록을 로드할 수 없습니다.",
    "Configure the default notification settings for new users." : "새 사용자의 기본 알림 설정을 변경합니다."
},
"nplurals=1; plural=0;");

==> php81-nextcloud-28.0.6.tgz: share/nextcloud/apps/activity/l10n/ko.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "%s 님의 개인 활동 피드",
    "Your feed URL is invalid" : "피드 주소가 잘못되었습니다",
    "Activity feed for %1$s" : "%1$s의 활동 피드",
    "Activity feed" : "활동 피드",
    "Your settings have been updated." : "설정이 업데이트되었습니다.",
    "Settings have been updated." : "설정이 업데이트되었습니다.",
    "Recent activity" : "최근 활동",
    "No activities" : "활동 없음",
    "More activities" : "더 많은 활동",
    "Daily activity summary for %s" : "%s 의 일일 활동 요약",
    "_and %n more _::_and %n more _" : ["%n개 더"],
    "All activities" : "모든 활동",
    "By others" : "다른 사람",
    "By you" : "나",
    "Activity at %s" : "%s에 활동",
    "Hello %s" : "%s 님 안녕하세요",
    "Hello %s," : "%s 님 안녕하세요,",
    "There was some activity at %s" : "%s에 새로운 활동이 있었습니다",
    "Mail" : "메일",
    "Push" : "푸시",
    "Activity" : "활동",
    "Notifications" : "알림",
    "This application enables people to view a log of activities about them, their files or other data." : "이 애플리케이션은 사용자, 파일, 혹은 기타 데이터와 관련된 활동 내역을 볼 수 있도록 합니다.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "이 앱은 Nextcloud에 존재하는 사용자의 파일, 데이터 관련 활동을 볼 수 있도록 합니다.\n\n\t\t각 사용자는 개인 설정에서 개인 활동에 관한 설정을 할 수 있습니다.\n\t\t특정 활동을 지정하여 푸시 알림, 이메일 알림을 전송하거나\n\t\t매일 아침 요악본을 발송하도록 할 수 있습니다.\n\t\t더 자세한 정보는 Activity 문서를 참고하십시오.",
    "Activity notification configuration" : "활동 알림 설정",
    "Send email" : "이메일 보내기",
    "Send push notification" : "푸시 알림 발송",
    "Today" : "오늘",
    "Yesterday" : "어제",
    "You need to set up your email address before you can receive notification emails." : "알림 이메일을 받으려면 이메일 주소를 설정해야 합니다.",
    "Send activity emails" : "활동 이메일 보내기",
    "As soon as possible" : "빠른 시일 내에",
    "Hourly" : "1시간마다",
    "Daily" : "매일",
    "Weekly" : "매주",
    "You commented" : "댓글 남김",
    "Message deleted by author" : "작성자가 메시지를 삭제함",
    "Open {filename}" : "{filename} 열기",
    "in {path}" : "{path}에 있음",
    "Home" : "홈",
    "Loading activities" : "활동 불러오는 중",
    "This stream will show events like additions, changes & shares" : "스트림에는 추가, 변경, 공유와 같은 이벤트가 표시됩니다",
    "No activity yet" : "아직 활동 없음",
    "Loading more activities" : "더 많은 활동 불러오는 중",
    "No more activities." : "더 이상 활동이 없습니다.",
    "Could not load activities" : "활동을 불러올 수 없습니다",
    "Activity settings" : "활동 설정",
    "Enable RSS feed" : "RSS 피드 사용",
    "RSS feed" : "RSS 피드",
    "Copy RSS feed link" : "RSS 피드 링크 복사",
    "Personal notification settings" : "개인 알림 설정",
    "Could not enable RSS link" : "RSS 링크를 활성화할 수 없습니다",
    "RSS link copied to clipboard" : "RSS 링크가 클립보드에 복사되었습니다",
    "Could not copy the RSS link, please copy manually:" : "RSS 링크를 복사할 수 없습니다. 직접 복사해 주세요:",
    "Unable to load the activity list" : "활동 목록을 로드할 수 없습니다.",
    "Notification" : "알림",
    "Enable notification emails" : "이메일 알림 활성화",
    "Choose for which activities you want to get an email or push notification." : "이메일 혹은 푸시 알림을 받을 활동을 선택합니다.",
    "Choose for which activities you want to get a push notification." : "푸시 알림을 받을 활동을 선택합니다.",
    "Daily activity summary" : "일간 활동 요약",
    "Send daily activity summary in the morning" : "매일 아침 일일 활동내역 전송",
    "Default settings" : "기본 설정",
    "Configure the default notification settings for new accounts." : "알림에 관한 기본값을 설정하십시오.",
    "Unable to save the settings" : "설정을 저장할 수 없습니다.",
    "No more events to load" : "더 이상 불러올 이벤트 없음",
    "Copied!" : "복사 성공!",
    "Not supported!" : "지원하지 않음!",
    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
    "{name} (invisible)" : "{name} (숨겨짐)",
    "{name} (restricted)" : "{name} (제한됨)",
    "There are no events for this filter" : "이 필터를 만족하는 이벤트 없음",
    "Could not load activites" : "활동을 불러올 수 없습니다"
},
"nplurals=1; plural=0;");
